@@ -73,7 +73,8 @@ def is_corn_or_soybeans(item_name: str) -> str:
 
 class GroCropClient(object):
 
-    def __init__(self, api_host=API_HOST, access_token=None):
+    def __init__(self, api_host=API_HOST, access_token=None, proxy_host=None, proxy_port=None,
+                 proxy_username=None, proxy_pass=None):
         """Construct a GroCropClient instance.
         Parameters
         ----------
@@ -85,6 +86,20 @@ class GroCropClient(object):
             Your Gro API authentication token. If not specified, the
             :code:`$GROAPI_TOKEN` environment variable is used. See
             :doc:`authentication`.
+        proxy_host : string, optional
+            If you're instantiating the GroCropClient behind a proxy, you'll need to 
+            provide the proxy_host to properly send requests using the groclient 
+            library.
+        proxy_port : int, optional
+            If you're instantiating the GroCropClient behind a proxy, you'll need to 
+            provide the proxy_port to properly send requests using the groclient 
+            library.
+        proxy_username : string, optional 
+            If you're instantiating the GroCropClient behind a proxy, and your proxy 
+            requires a username and password, you'll need to provide the proxy_username.
+        proxy_pass : string optional
+            Password for your proxy username.
+        
         Raises
         ------
             RuntimeError
@@ -103,7 +118,17 @@ class GroCropClient(object):
                                    "Your Gro Client is constructed without the access_token argument")
         self._api_host = api_host
         self._access_token = access_token
-        self._client = GroClient(self._api_host, self._access_token)
+        self._proxy_host = proxy_host
+        self._proxy_port = proxy_port
+        self._proxy_username = proxy_username
+        self._proxy_pass = proxy_pass
+
+        self._client = GroClient(api_host = self._api_host, 
+                                 access_token = self._access_token, 
+                                 proxy_host = self._proxy_host,
+                                 proxy_port = self._proxy_port,
+                                 proxy_username = self._proxy_username,
+                                 proxy_pass = self._proxy_pass)
 
     def get_sources(self):
         """Returns a list of all US Crop sources, as JSON.
